==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-pipeline-management/src/main/java/org/apache/streampipes/manager/execution/PipelineExecutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.execution;

import org.apache.streampipes.manager.execution.task.PipelineExecutionTask;
import org.apache.streampipes.model.pipeline.Pipeline;
import org.apache.streampipes.model.pipeline.PipelineOperationStatus;

import java.util.List;

public class PipelineExecutor {

  private final Pipeline pipeline;
  private final boolean forceStop;

  public PipelineExecutor(Pipeline pipeline,
                          boolean forceStop) {
    this.pipeline = pipeline;
    this.forceStop = forceStop;
  }

  public PipelineOperationStatus startPipeline() {
    return executeOperation(PipelineExecutionTaskFactory.makeStartPipelineTasks(pipeline));
  }

  public PipelineOperationStatus stopPipeline() {
    return executeOperation(PipelineExecutionTaskFactory.makeStopPipelineTasks(pipeline, forceStop));
  }

  private PipelineOperationStatus executeOperation(List<PipelineExecutionTask> executionTasks) {
    var executionInfo = PipelineExecutionInfo.create(pipeline);
    executionTasks
        .forEach(task -> {
          if (task.shouldExecute(executionInfo)) {
            task.executeTask(pipeline, executionInfo);
          }
        });
    return executionInfo.getPipelineOperationStatus();
  }

}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-pipeline-management/src/main/java/org/apache/streampipes/manager/execution/PipelineExecutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.execution;

import org.apache.streampipes.manager.execution.task.PipelineExecutionTask;
import org.apache.streampipes.model.pipeline.Pipeline;
import org.apache.streampipes.model.pipeline.PipelineOperationStatus;

import java.util.List;

public class PipelineExecutor {

  private final Pipeline pipeline;

  public PipelineExecutor(Pipeline pipeline) {
    this.pipeline = pipeline;
  }

  public PipelineOperationStatus startPipeline() {
    return executeOperation(PipelineExecutionTaskFactory.makeStartPipelineTasks(pipeline));
  }

  public PipelineOperationStatus stopPipeline(boolean forceStop) {
    return executeOperation(PipelineExecutionTaskFactory.makeStopPipelineTasks(pipeline, forceStop));
  }

  private PipelineOperationStatus executeOperation(List<PipelineExecutionTask> executionTasks) {
    var executionInfo = PipelineExecutionInfo.create(pipeline);
    executionTasks
        .forEach(task -> {
          if (task.shouldExecute(executionInfo)) {
            task.executeTask(pipeline, executionInfo);
          }
        });
    return executionInfo.getPipelineOperationStatus();
  }

}
